@@ -3,6 +3,8 @@
 """
 # 是否检查可调用的方法。
 # !!! 生产环境中请不要随意关闭，否则权限过大
+from IPy import IP
+
 METHODS_CHECK = False
 
 # 允许的方法
@@ -55,6 +57,20 @@ METHODS_BLOCK = {
     'demo': True,
 }
 
+# 是否进行IP检查，屏蔽外网访问
+IP_CHECK = True
+
+IP_ALLOW = {
+    IP('127.0.0.0/8'): True,  # 回环地址
+    IP('192.168.0.0/16'): True,  # C类内网
+    IP('172.16.0.0/12'): True,  # B类内网
+    IP('10.0.0.0/8'): True,  # A类内网
+}
+IP_BLOCK = {
+    IP('8.8.8.8/32'): False,
+    IP('8.8.4.4/32'): False,
+}
+
 # 缓存类型。生产环境请配置redis服务
 CACHE_TYPE = 'fakeredis'  # fakeredis, aioredis
 # 缓存服务地址
@@ -68,9 +84,6 @@ AUTH_TOKENS = {
     "secret-token-2": "susan",
 }
 
-# 是否进行IP检查，屏蔽外网访问
-IP_CHECK = True
-
 # 聚宽账号
 JQ_USERNAME = '13912345678'
 JQ_PASSWORD = '12345678'
